<?php

/**
 * This is the base migration util containing generic migration helper methods
 * Class/Plugin specific migration helpers can extend from this one
 */
class BaseMigrationModelUtil {

	public $Model = null;

/**
 * Constructor for a model migration helper
 *
 * @param string $modelName Name of base model for the helper which will be loaded through EvClassRegistry::init
 */
	public function __construct($modelName) {
		$this->Model = EvClassRegistry::init($modelName);
	}

/**
 * Function to only create a record if it doesn't already exist
 *
 * @param array $conditions Conditions array to check if the record already exists or not
 * @param array $data       Data to pass into Model->saveAssociated if the record doesn't already exist
 * @return int|bool         Primary key of the created or existing record, false if it fails
 */
	public function createOnce($conditions, $data) {
		// Check if the record already exists
		if ($this->Model->find('first', ['conditions' => $conditions])) {
			return $this->Model->id;
		}

		// Record didn't exist so create it
		$this->Model->create();
		$success = (bool)$this->Model->saveAssociated($data, ['deep' => true]);

		return $success ? $this->Model->id : false;
	}

/**
 * Deletes the first record met by the given conditions
 *
 * @param array $conditions Conditions array to delete a record by
 * @return bool             Returns true if the delete suceeds or the record doesn't exists
 */
	public function deleteIfExists($conditions) {
		// Check if the record already exists
		if ($record = $this->Model->find('first', ['conditions' => $conditions])) {
			return $this->Model->delete($record->id);
		}

		return true;
	}

/**
 * Deletes all records that meet the conditions, alais for Model::delete
 *
 * @param array $conditions Conditions array to delete records by
 * @param bool $cascade Set to true to delete records that depend on this record
 * @param bool $callbacks Run callbacks
 * @return bool True on success, false on failure
 * @link http://book.cakephp.org/2.0/en/models/deleting-data.html#deleteall
 */
	public function deleteAll($conditions, $cascade = true, $callbacks = false) {
		return $this->Model->deleteAll($conditions, $cascade, $callbacks);
	}

}
